<?php

/**
 * @file entity_enqueue.drush.inc
 *   Drush integration for Entity Enqueue.
 */

/**
 * Implementation of hook_drush_command().
 */
function entity_enqueue_drush_command() {
  $items = array();

  $data_option = array(
    'description' => dt('Arbitrary data to be associated with the new task in the queue, JSON-encoded.'),
    'example-value' => '{\'parent_nid\':517}',
    'value' => 'required',
  );

  $items['entity-enqueue'] = array(
    'description' => dt('Enqueue an entity into a Drupal queue.'),
    'required-arguments' => TRUE,
    'arguments' => array(
      'queue_name' => dt('Queue name where to enqueue the entity.'),
      'entity_id' => dt('Entity ID to enqueue.'),
    ),
    'options' => array(
      'type' => array(
        'description' => dt('Optional. Specify entity type. Default is \'node\'.'),
        'example-value' => 'node,user,file,...',
        'value' => 'required',
      ),
      'data' => $data_option,
    ),
    'bootstrap' => DRUSH_BOOTSTRAP_DRUPAL_FULL,
    'aliases' => array('eeq'),
    'examples' => array(
      'drush entity-enqueue my-queue 1' => 'Enqueues entity ID 1 of default entity type (node) into \'my-queue\' queue',
      'drush entity-enqueue my-queue 1 --type=user' => 'Enqueues user 1 into \'my-queue\' queue',
    ),
  );

  $items['entity-enqueue-file'] = array(
    'description' => dt('Enqueue a managed file into a Drupal queue.'),
    'required-arguments' => TRUE,
    'arguments' => array(
      'queue_name' => dt('Queue name where to enqueue the file.'),
      'fid' => dt('File ID to enqueue.'),
    ),
    'options' => array(
      'data' => $data_option,
     ),
    'bootstrap' => DRUSH_BOOTSTRAP_DRUPAL_FULL,
    'aliases' => array('eeqf'),
    'examples' => array(
      'drush entity-enqueue-file my-queue 1' => 'Enqueues File ID 1 into \'my-queue\' queue.',
    ),
  );

  $items['entity-enqueue-node'] = array(
    'description' => dt('Enqueue a node into a Drupal queue.'),
    'required-arguments' => TRUE,
    'arguments' => array(
      'queue_name' => dt('Queue name where to enqueue the node.'),
      'nid'  => dt('Node ID to enqueue.'),
    ),
    'options' => array(
      'data' => $data_option,
    ),
    'bootstrap' => DRUSH_BOOTSTRAP_DRUPAL_FULL,
    'aliases' => array('eeqn'),
    'examples' => array(
      'drush entity-enqueue-node my-queue 1' => 'Enqueues Node ID 1 into \'my-queue\' queue.',
    ),
  );

  $items['entity-enqueue-user'] = array(
    'description' => dt('Enqueue a user into a Drupal queue.'),
    'required-arguments' => TRUE,
    'arguments' => array(
      'queue_name' => dt('Queue name where to enqueue the user.'),
      'uid' => dt('User ID to enqueue.'),
    ),
    'bootstrap' => DRUSH_BOOTSTRAP_DRUPAL_FULL,
    'aliases' => array('eequ'),
    'examples' => array(
      'drush entity-enqueue-user my-queue 1' => 'Enqueues User ID 1 into \'my-queue\' queue.',
    ),
  );

  return $items;
}

function drush_entity_enqueue($queue_name, $entity_id) {
  $entity_type = drush_get_option('type', 'node');
  $data = _drush_entity_enqueue_get_data_option();

  entity_enqueue_entity($queue_name, $entity_id, $entity_type, $data);
}

function drush_entity_enqueue_file($queue_name, $fid) {
  $data = _drush_entity_enqueue_get_data_option();

  entity_enqueue_file_fid($queue_name, $fid, $data);
}

function drush_entity_enqueue_node($queue_name, $nid) {
  $data = _drush_entity_enqueue_get_data_option();

  entity_enqueue_node_nid($queue_name, $nid, $data);
}

function drush_entity_enqueue_user($queue_name, $uid) {
  $data = _drush_entity_enqueue_get_data_option();

  entity_enqueue_user_uid($queue_name, $uid, $data);
}

/**
 * Command argument complete callback. Provides argument
 * values for shell completion.
 *
 * @return
 *  Array of popular fillings.
 */
function entity_enqueue_entity_enqueue_complete() {
  drush_bootstrap(DRUSH_BOOTSTRAP_DRUPAL_FULL);
  return array(
    'values' => array_keys(module_invoke_all('cron_queue_info')),
  );
}

function _drush_entity_enqueue_get_data_option() {
  $data = drush_get_option('data', array());

  if (!empty($data)) {
    drush_log('Data (string): ' . print_r($data, TRUE), 'notice');

    $data = json_decode($data, TRUE);
    drush_log('Data (decoded):' . PHP_EOL . trim(print_r($data, TRUE)), 'notice');
  }
  return $data;
}
